@@ -7,4 +7,4 @@ if [ ! -e /dev/net/tun ]; then
 	exit 1
 fi
 
-exec /zerotier-one
+exec "$@"
