@@ -1,15 +1,10 @@
-/*
- * Copyright (c)2013-2021 ZeroTier, Inc.
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * Use of this software is governed by the Business Source License included
- * in the LICENSE.TXT file in the project's root directory.
- *
- * Change Date: 2026-01-01
- *
- * On the date above, in accordance with the Business Source License, use
- * of this software will be governed by version 2.0 of the Apache License.
+ * (c) ZeroTier, Inc.
+ * https://www.zerotier.com/
  */
-/****/
 
 #ifndef ZT_BOND_HPP
 #define ZT_BOND_HPP
@@ -23,7 +18,6 @@
 
 #include <cstdarg>
 #include <deque>
-#include <list>
 #include <map>
 
 /**
@@ -1144,7 +1138,7 @@ class Bond {
 		__attribute__((format(printf, 2, 3)))
 #endif
 	{
-		//if (_peerId != 0x0 && _peerId != 0x0) { return; }
+		// if (_peerId != 0x0 && _peerId != 0x0) { return; }
 #ifdef ZT_TRACE
 		time_t rawtime;
 		struct tm* timeinfo;
@@ -1176,7 +1170,7 @@ class Bond {
 		__attribute__((format(printf, 2, 3)))
 #endif
 	{
-		//if (_peerId != 0x0 && _peerId != 0x0) { return; }
+		// if (_peerId != 0x0 && _peerId != 0x0) { return; }
 #ifdef ZT_DEBUG
 		time_t rawtime;
 		struct tm* timeinfo;
