@@ -1,31 +1,22 @@
-/*
- * Copyright (c)2019 ZeroTier, Inc.
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * Use of this software is governed by the Business Source License included
- * in the LICENSE.TXT file in the project's root directory.
- *
- * Change Date: 2026-01-01
- *
- * On the date above, in accordance with the Business Source License, use
- * of this software will be governed by version 2.0 of the Apache License.
+ * (c) ZeroTier, Inc.
+ * https://www.zerotier.com/
  */
-/****/
 
 #ifndef ZT_BUFFER_HPP
 #define ZT_BUFFER_HPP
 
-#include <string.h>
-#include <stdint.h>
-
-#include <stdexcept>
-#include <string>
-#include <algorithm>
-#include <utility>
-
 #include "Constants.hpp"
 #include "Utils.hpp"
 
-#if defined(__GNUC__) && (!defined(ZT_NO_TYPE_PUNNING))
+#include <algorithm>
+#include <stdint.h>
+#include <string.h>
+
+#if defined(__GNUC__) && (! defined(ZT_NO_TYPE_PUNNING))
 #define ZT_VAR_MAY_ALIAS __attribute__((__may_alias__))
 #else
 #define ZT_VAR_MAY_ALIAS
@@ -46,36 +37,57 @@ namespace ZeroTier {
  *
  * @tparam C Total capacity
  */
-template<unsigned int C>
-class Buffer
-{
+template <unsigned int C> class Buffer {
 	// I love me!
 	template <unsigned int C2> friend class Buffer;
 
-public:
+  public:
 	// STL container idioms
 	typedef unsigned char value_type;
-	typedef unsigned char * pointer;
-	typedef const char * const_pointer;
-	typedef char & reference;
-	typedef const char & const_reference;
-	typedef char * iterator;
-	typedef const char * const_iterator;
+	typedef unsigned char* pointer;
+	typedef const char* const_pointer;
+	typedef char& reference;
+	typedef const char& const_reference;
+	typedef char* iterator;
+	typedef const char* const_iterator;
 	typedef unsigned int size_type;
 	typedef int difference_type;
 	typedef std::reverse_iterator<iterator> reverse_iterator;
 	typedef std::reverse_iterator<const_iterator> const_reverse_iterator;
-	inline iterator begin() { return _b; }
-	inline iterator end() { return (_b + _l); }
-	inline const_iterator begin() const { return _b; }
-	inline const_iterator end() const { return (_b + _l); }
-	inline reverse_iterator rbegin() { return reverse_iterator(begin()); }
-	inline reverse_iterator rend() { return reverse_iterator(end()); }
-	inline const_reverse_iterator rbegin() const { return const_reverse_iterator(begin()); }
-	inline const_reverse_iterator rend() const { return const_reverse_iterator(end()); }
+	inline iterator begin()
+	{
+		return _b;
+	}
+	inline iterator end()
+	{
+		return (_b + _l);
+	}
+	inline const_iterator begin() const
+	{
+		return _b;
+	}
+	inline const_iterator end() const
+	{
+		return (_b + _l);
+	}
+	inline reverse_iterator rbegin()
+	{
+		return reverse_iterator(begin());
+	}
+	inline reverse_iterator rend()
+	{
+		return reverse_iterator(end());
+	}
+	inline const_reverse_iterator rbegin() const
+	{
+		return const_reverse_iterator(begin());
+	}
+	inline const_reverse_iterator rend() const
+	{
+		return const_reverse_iterator(end());
+	}
 
-	Buffer() :
-		_l(0)
+	Buffer() : _l(0)
 	{
 	}
 
@@ -87,37 +99,36 @@ public:
 		_l = l;
 	}
 
-	template<unsigned int C2>
-	Buffer(const Buffer<C2> &b)
+	template <unsigned int C2> Buffer(const Buffer<C2>& b)
 	{
 		*this = b;
 	}
 
-	Buffer(const void *b,unsigned int l)
+	Buffer(const void* b, unsigned int l)
 	{
-		copyFrom(b,l);
+		copyFrom(b, l);
 	}
 
-	template<unsigned int C2>
-	inline Buffer &operator=(const Buffer<C2> &b)
+	template <unsigned int C2> inline Buffer& operator=(const Buffer<C2>& b)
 	{
 		if (unlikely(b._l > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
 		if (C2 == C) {
-			memcpy(this,&b,sizeof(Buffer<C>));
-		} else {
-			memcpy(_b,b._b,_l = b._l);
+			memcpy(this, &b, sizeof(Buffer<C>));
+		}
+		else {
+			memcpy(_b, b._b, _l = b._l);
 		}
 		return *this;
 	}
 
-	inline void copyFrom(const void *b,unsigned int l)
+	inline void copyFrom(const void* b, unsigned int l)
 	{
 		if (unlikely(l > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		memcpy(_b,b,l);
+		memcpy(_b, b, l);
 		_l = l;
 	}
 
@@ -129,12 +140,12 @@ public:
 		return (unsigned char)_b[i];
 	}
 
-	unsigned char &operator[](const unsigned int i)
+	unsigned char& operator[](const unsigned int i)
 	{
 		if (unlikely(i >= _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		return ((unsigned char *)_b)[i];
+		return ((unsigned char*)_b)[i];
 	}
 
 	/**
@@ -150,19 +161,19 @@ public:
 	 * @return Pointer to field data
 	 * @throws std::out_of_range Field extends beyond data size
 	 */
-	unsigned char *field(unsigned int i,unsigned int l)
+	unsigned char* field(unsigned int i, unsigned int l)
 	{
 		if (unlikely((i + l) > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		return (unsigned char *)(_b + i);
+		return (unsigned char*)(_b + i);
 	}
-	const unsigned char *field(unsigned int i,unsigned int l) const
+	const unsigned char* field(unsigned int i, unsigned int l) const
 	{
 		if (unlikely((i + l) > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		return (const unsigned char *)(_b + i);
+		return (const unsigned char*)(_b + i);
 	}
 
 	/**
@@ -172,19 +183,18 @@ public:
 	 * @param v Value
 	 * @tparam T Integer type (e.g. uint16_t, int64_t)
 	 */
-	template<typename T>
-	inline void setAt(unsigned int i,const T v)
+	template <typename T> inline void setAt(unsigned int i, const T v)
 	{
 		if (unlikely((i + sizeof(T)) > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
 #ifdef ZT_NO_TYPE_PUNNING
-		uint8_t *p = reinterpret_cast<uint8_t *>(_b + i);
-		for(unsigned int x=1;x<=sizeof(T);++x) {
+		uint8_t* p = reinterpret_cast<uint8_t*>(_b + i);
+		for (unsigned int x = 1; x <= sizeof(T); ++x) {
 			*(p++) = (uint8_t)(v >> (8 * (sizeof(T) - x)));
 		}
 #else
-		T *const ZT_VAR_MAY_ALIAS p = reinterpret_cast<T *>(_b + i);
+		T* const ZT_VAR_MAY_ALIAS p = reinterpret_cast<T*>(_b + i);
 		*p = Utils::hton(v);
 #endif
 	}
@@ -196,22 +206,21 @@ public:
 	 * @tparam T Integer type (e.g. uint16_t, int64_t)
 	 * @return Integer value
 	 */
-	template<typename T>
-	inline T at(unsigned int i) const
+	template <typename T> inline T at(unsigned int i) const
 	{
 		if (unlikely((i + sizeof(T)) > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
 #ifdef ZT_NO_TYPE_PUNNING
 		T v = 0;
-		const uint8_t *p = reinterpret_cast<const uint8_t *>(_b + i);
-		for(unsigned int x=0;x<sizeof(T);++x) {
+		const uint8_t* p = reinterpret_cast<const uint8_t*>(_b + i);
+		for (unsigned int x = 0; x < sizeof(T); ++x) {
 			v <<= 8;
-			v |= (T)*(p++);
+			v |= (T) * (p++);
 		}
 		return v;
 #else
-		const T *const ZT_VAR_MAY_ALIAS p = reinterpret_cast<const T *>(_b + i);
+		const T* const ZT_VAR_MAY_ALIAS p = reinterpret_cast<const T*>(_b + i);
 		return Utils::ntoh(*p);
 #endif
 	}
@@ -223,19 +232,18 @@ public:
 	 * @tparam T Integer type (e.g. uint16_t, int64_t)
 	 * @throws std::out_of_range Attempt to append beyond capacity
 	 */
-	template<typename T>
-	inline void append(const T v)
+	template <typename T> inline void append(const T v)
 	{
 		if (unlikely((_l + sizeof(T)) > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
 #ifdef ZT_NO_TYPE_PUNNING
-		uint8_t *p = reinterpret_cast<uint8_t *>(_b + _l);
-		for(unsigned int x=1;x<=sizeof(T);++x) {
+		uint8_t* p = reinterpret_cast<uint8_t*>(_b + _l);
+		for (unsigned int x = 1; x <= sizeof(T); ++x) {
 			*(p++) = (uint8_t)(v >> (8 * (sizeof(T) - x)));
 		}
 #else
-		T *const ZT_VAR_MAY_ALIAS p = reinterpret_cast<T *>(_b + _l);
+		T* const ZT_VAR_MAY_ALIAS p = reinterpret_cast<T*>(_b + _l);
 		*p = Utils::hton(v);
 #endif
 		_l += sizeof(T);
@@ -248,12 +256,12 @@ public:
 	 * @param n Number of times to append
 	 * @throws std::out_of_range Attempt to append beyond capacity
 	 */
-	inline void append(unsigned char c,unsigned int n)
+	inline void append(unsigned char c, unsigned int n)
 	{
 		if (unlikely((_l + n) > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		for(unsigned int i=0;i<n;++i) {
+		for (unsigned int i = 0; i < n; ++i) {
 			_b[_l++] = (char)c;
 		}
 	}
@@ -268,7 +276,7 @@ public:
 		if (unlikely((_l + n) > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		Utils::getSecureRandom(_b + _l,n);
+		Utils::getSecureRandom(_b + _l, n);
 		_l += n;
 	}
 
@@ -279,12 +287,12 @@ public:
 	 * @param l Length
 	 * @throws std::out_of_range Attempt to append beyond capacity
 	 */
-	inline void append(const void *b,unsigned int l)
+	inline void append(const void* b, unsigned int l)
 	{
 		if (unlikely((_l + l) > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		memcpy(_b + _l,b,l);
+		memcpy(_b + _l, b, l);
 		_l += l;
 	}
 
@@ -294,13 +302,13 @@ public:
 	 * @param s C string
 	 * @throws std::out_of_range Attempt to append beyond capacity
 	 */
-	inline void appendCString(const char *s)
+	inline void appendCString(const char* s)
 	{
-		for(;;) {
+		for (;;) {
 			if (unlikely(_l >= C)) {
 				throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 			}
-			if (!(_b[_l++] = *(s++))) {
+			if (! (_b[_l++] = *(s++))) {
 				break;
 			}
 		}
@@ -313,10 +321,9 @@ public:
 	 * @tparam C2 Capacity of second buffer (typically inferred)
 	 * @throws std::out_of_range Attempt to append beyond capacity
 	 */
-	template<unsigned int C2>
-	inline void append(const Buffer<C2> &b)
+	template <unsigned int C2> inline void append(const Buffer<C2>& b)
 	{
-		append(b._b,b._l);
+		append(b._b, b._l);
 	}
 
 	/**
@@ -329,12 +336,12 @@ public:
 	 * @param l Length of field to append
 	 * @return Pointer to beginning of appended field of length 'l'
 	 */
-	inline char *appendField(unsigned int l)
+	inline char* appendField(unsigned int l)
 	{
 		if (unlikely((_l + l) > C)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		char *r = _b + _l;
+		char* r = _b + _l;
 		_l += l;
 		return r;
 	}
@@ -379,13 +386,13 @@ public:
 	 */
 	inline void behead(const unsigned int at)
 	{
-		if (!at) {
+		if (! at) {
 			return;
 		}
 		if (unlikely(at > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		::memmove(_b,_b + at,_l -= at);
+		::memmove(_b, _b + at, _l -= at);
 	}
 
 	/**
@@ -395,92 +402,110 @@ public:
 	 * @param length Length of block to erase
 	 * @throws std::out_of_range Position plus length is beyond size of buffer
 	 */
-	inline void erase(const unsigned int at,const unsigned int length)
+	inline void erase(const unsigned int at, const unsigned int length)
 	{
 		const unsigned int endr = at + length;
 		if (unlikely(endr > _l)) {
 			throw ZT_EXCEPTION_OUT_OF_BOUNDS;
 		}
-		::memmove(_b + at,_b + endr,_l - endr);
+		::memmove(_b + at, _b + endr, _l - endr);
 		_l -= length;
 	}
 
 	/**
 	 * Set buffer data length to zero
 	 */
-	inline void clear() { _l = 0; }
+	inline void clear()
+	{
+		_l = 0;
+	}
 
 	/**
 	 * Zero buffer up to size()
 	 */
-	inline void zero() { memset(_b,0,_l); }
+	inline void zero()
+	{
+		memset(_b, 0, _l);
+	}
 
 	/**
 	 * Zero unused capacity area
 	 */
-	inline void zeroUnused() { memset(_b + _l,0,C - _l); }
+	inline void zeroUnused()
+	{
+		memset(_b + _l, 0, C - _l);
+	}
 
 	/**
 	 * Unconditionally and securely zero buffer's underlying memory
 	 */
-	inline void burn() { Utils::burn(_b,sizeof(_b)); }
+	inline void burn()
+	{
+		Utils::burn(_b, sizeof(_b));
+	}
 
 	/**
 	 * @return Constant pointer to data in buffer
 	 */
-	inline const void *data() const { return _b; }
+	inline const void* data() const
+	{
+		return _b;
+	}
 
 	/**
 	 * @return Non-constant pointer to data in buffer
 	 */
-	inline void *unsafeData() { return _b; }
+	inline void* unsafeData()
+	{
+		return _b;
+	}
 
 	/**
 	 * @return Size of data in buffer
 	 */
-	inline unsigned int size() const { return _l; }
+	inline unsigned int size() const
+	{
+		return _l;
+	}
 
 	/**
 	 * @return Capacity of buffer
 	 */
-	inline unsigned int capacity() const { return C; }
+	inline unsigned int capacity() const
+	{
+		return C;
+	}
 
-	template<unsigned int C2>
-	inline bool operator==(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator==(const Buffer<C2>& b) const
 	{
-		return ((_l == b._l)&&(!memcmp(_b,b._b,_l)));
+		return ((_l == b._l) && (! memcmp(_b, b._b, _l)));
 	}
-	template<unsigned int C2>
-	inline bool operator!=(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator!=(const Buffer<C2>& b) const
 	{
-		return ((_l != b._l)||(memcmp(_b,b._b,_l)));
+		return ((_l != b._l) || (memcmp(_b, b._b, _l)));
 	}
-	template<unsigned int C2>
-	inline bool operator<(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator<(const Buffer<C2>& b) const
 	{
-		return (memcmp(_b,b._b,std::min(_l,b._l)) < 0);
+		return (memcmp(_b, b._b, std::min(_l, b._l)) < 0);
 	}
-	template<unsigned int C2>
-	inline bool operator>(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator>(const Buffer<C2>& b) const
 	{
 		return (b < *this);
 	}
-	template<unsigned int C2>
-	inline bool operator<=(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator<=(const Buffer<C2>& b) const
 	{
-		return !(b < *this);
+		return ! (b < *this);
 	}
-	template<unsigned int C2>
-	inline bool operator>=(const Buffer<C2> &b) const
+	template <unsigned int C2> inline bool operator>=(const Buffer<C2>& b) const
 	{
-		return !(*this < b);
+		return ! (*this < b);
 	}
 
-private:
+  private:
 	char ZT_VAR_MAY_ALIAS _b[C];
 	unsigned int _l;
 };
 
-} // namespace ZeroTier
+}	// namespace ZeroTier
 
 #endif
