@@ -1,28 +1,23 @@
-/*
- * Copyright (c)2019 ZeroTier, Inc.
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * Use of this software is governed by the Business Source License included
- * in the LICENSE.TXT file in the project's root directory.
- *
- * Change Date: 2026-01-01
- *
- * On the date above, in accordance with the Business Source License, use
- * of this software will be governed by version 2.0 of the Apache License.
+ * (c) ZeroTier, Inc.
+ * https://www.zerotier.com/
  */
-/****/
 
 #ifdef ZT_USE_MINIUPNPC
 
 #ifndef ZT_PORTMAPPER_HPP
 #define ZT_PORTMAPPER_HPP
 
-#include <vector>
-
 #include "../node/Constants.hpp"
 #include "../node/InetAddress.hpp"
 #include "../node/Mutex.hpp"
 #include "Thread.hpp"
 
+#include <vector>
+
 /**
  * How frequently should we refresh our UPNP/NAT-PnP/whatever state?
  */
@@ -35,18 +30,17 @@ class PortMapperImpl;
 /**
  * UPnP/NAT-PnP port mapping "daemon"
  */
-class PortMapper
-{
+class PortMapper {
 	friend class PortMapperImpl;
 
-public:
+  public:
 	/**
 	 * Create and start port mapper service
 	 *
 	 * @param localUdpPortToMap Port we want visible to the outside world
 	 * @param name Unique name of this endpoint (based on ZeroTier address)
 	 */
-	PortMapper(int localUdpPortToMap,const char *uniqueName);
+	PortMapper(int localUdpPortToMap, const char* uniqueName);
 
 	~PortMapper();
 
@@ -55,12 +49,12 @@ public:
 	 */
 	std::vector<InetAddress> get() const;
 
-private:
-	PortMapperImpl *_impl;
+  private:
+	PortMapperImpl* _impl;
 };
 
-} // namespace ZeroTier
+}	// namespace ZeroTier
 
 #endif
 
-#endif // ZT_USE_MINIUPNPC
+#endif	 // ZT_USE_MINIUPNPC
