@@ -8,7 +8,7 @@ fn main() {
     let crate_dir = env::var("CARGO_MANIFEST_DIR").unwrap();
 
     let package_name = env::var("CARGO_PKG_NAME").unwrap();
-    let output_file = target_dir().join(format!("{}.h", package_name)).display().to_string();
+    let output_file = target_dir().join(format!("{package_name}.h")).display().to_string();
 
     let config = Config {
         language: Language::C,
