@@ -1,9 +1,9 @@
-#define PRODUCT_NAME			"ZeroTier One Virtual Port"
+#define PRODUCT_NAME			"ZeroTier Virtual Port"
 #define PRODUCT_VERSION			"3.0.0"
 #define PRODUCT_VERSION_RESOURCE	3,0,0,1
 #define PRODUCT_TAP_WIN_COMPONENT_ID	"zttap300"
 #define PRODUCT_TAP_WIN_MAJOR		3
 #define PRODUCT_TAP_WIN_MINOR		0
-#define PRODUCT_TAP_WIN_PROVIDER		"ZeroTier Networks"
+#define PRODUCT_TAP_WIN_PROVIDER		"ZeroTier"
 #define PRODUCT_TAP_WIN_DEVICE_DESCRIPTION	PRODUCT_NAME
-#define PRODUCT_TAP_WIN_RELDATE		"04/25/2015"
+#define PRODUCT_TAP_WIN_RELDATE		"11/24/2020"
